@@ -1,5 +1,6 @@
 from .SURE import SURE
 from .DensityFlow import DensityFlow
+from .PerturbE import PerturbE
 
 from . import utils 
 from . import codebook
@@ -9,4 +10,4 @@ from . import atac
 from . import flow 
 from . import perturb
 
-__all__ = ['SURE', 'DensityFlow', 'flow', 'perturb', 'atac', 'utils', 'codebook']
\ No newline at end of file
+__all__ = ['SURE', 'DensityFlow', 'PerturbE', 'flow', 'perturb', 'atac', 'utils', 'codebook']
\ No newline at end of file
